__Author__='神秘的·'
__Project__='虹源三式'
#__version__='定制版'
link='https://pypi.org/project/sycc/#description/'
from time import sleep as dd
from sys import path
#from 
from random import uniform as float__wait_time
path.append('..')
from k.Mac import bs64
from os import popen
from os.path import exists,isfile
from tqdm._tqdm import trange

import sys as s, time as t
import threading
version=[]
#def A():#作者&运算符相关
#global ver_str
def sycc_ver():
    global ver_str
    ver_str=list(popen('pip show sycc').read().splitlines(False))
    def ver_outside():
        global ver_str
        ver_str=ver_str[1].split(':')[1].split('.')
    (threading.Thread(target=ver_outside)).start()
def wf():
    print('\r请稍等,全力加载中')  
    (threading.Thread(target=sycc_ver)).start()
    for i in trange(0,100):
        #s.stdout.write("██")
        dd_random=float__wait_time(0.08,0.13)
        dd(0.012)
        dd(dd_random)

    try:
        version.append(ver_str[0])
        version.append(ver_str[1])
        version.append(ver_str[2])
    except NameError:
        print('请耐心等待…')
        dd(2.5)
        try:
            del version[2]
            del version[1]
            del version[0]
        except Exception:
            try:
                del version[1]
                del version[0]
            except Exception:
                try:
                    del version[0]
                except:
                    global ver2
                    ver2='定制版'
        version.append(ver_str[0])
        version.append(ver_str[1])
        version.append(ver_str[2])
        
    if  len(version)>=3:
        print('\ndone!')
        dd(0.02)
    else:
        print('请等待几秒,子线程未运行完成',flush=True)
        dd(2)
        if len(version)>=3:
            print('\ndone!')
            dd(0.02)
        else:
            print('就再等几秒…')
            dd(3)
def A():
    try:
        __version__=version[0]+'.'+version[1]+'.'+version[2]
    except Exception:
        __version__=ver2
    print('\n\033[1;5;44m作者:' ,__Author__,'\033[0m')  
    print('\033[1;5;44m版本:',__version__,'\033[0m')
    print('\033[1;5;44mname:',__Project__,'\033[0m')
    print('\033[1;5;44mDescribe_README:',link,'\033[0m')
    dd(0.5)
    #print('\033[1;44m支持\033[0m','输入运算符(选项除外),\033[0m(使用英文字符)')
    dd(0.02)
pai2='π' #下面要用到，提前放上来 
def dw():#单位
    print('请自行换算单位并保持单位一致')
from math import pi as pai1
def aboutpi():
    print('''
    请选择π的值
    1.输入1,π为3.14
    2.输入2,π为''',pai1,
    '''
    3.输入3,保留π(π不换成数字)
    4.输入4,π自定义大小(大于3 ,小于3.2)
    其他选项:
    5.输入5,切换模式
    6.输入不是1~5中的数,直接退出''')
#wf();A()#test

    


# __init__.py
# .
import os
from colorama import init
from datetime import datetime as sj
from time import sleep as dd
from math import pi as pai1
from sys import exit as tc
from k.test import now_path,size
start=sj.now()
from p.pdsys import *
from v import *
import socket

#pypi_org()


import sys as s
from __init__ import * #排好顺序start变量覆盖
from p.__init__ import *
from k.test import *
from p.y import *
from p.yh import *
from p.yz import *
from p.qt import *
from p.beginnings import *

  
def pypi_org():
    s=socket.socket()
    s.settimeout(10)
    try:
        readme=open(now_path+'/.net.txt','a+')
        status = s.connect_ex(('pypi.org',443))
        if status == 0:
            s.close()
            return True
            if size(now_path+'/.net.txt')==0:
                save_v(1,now_path+'/.net.txt')
            else:
                pass
            if load_v(now_path+'/.net.txt')==1:
                import webbrowser
                open_web=6
                while open_web in range(1,7):
                    open_web=open_web-1
                    print('\r将在%ds后打开浏览器查看sycc的介绍,请勿关闭'%open_web,end='',flush=True)
                    dd(1)
                print('\n')
                webbrowser.open(link, new=0, autoraise=True)
                save_v(0,now_path+'/.net.txt') 
            else:
                pass
        else:
            pass
    except Exception as e:
        pass
def main():
    pdios();wf();A();pypi_org();user_key();#A()
    #print(version)
    print('\033[7;36m本次开始使用时间:\033[0m','\033[7;32m',start,'\b\b'+'\033[0m','\033[1;1m')
    while True:
        print('\033[1;1m','\b【虹源三式】'.center(5))
        print("===== 切换/选择模式，请选择 =====\n模式1.计算关于"+y_font+"的计算(输入1执行)\n模式2.计算关于"+yz_font+"的计算(输入2执行)\n模式3.计算关于\033[6;35m圆环\033[0m\033[1;1m的计算(输入3执行)\n模式4.计算关于"+qt_font+"的计算(输入4执行)\n输入其他字符退出\n")
        yyy=input('请选择模式(输入数字):')
        try:
            yyy=eval(yyy)
        except (IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            print('请输入正确数字')
        except ZeroDivisionError:
            print('除数不能为0')
        if yyy==1:
            part_y() 
        elif yyy==2:
            part_yz()
        elif yyy==3:
            part_yh()
        elif yyy==4:
            part_qt()            
        else:
            end=sj.now()-start
            print('即将\033[10;31m退出\033[0m,','本次使用时间:',end,'\n程序将在5秒后关闭,谢谢使用')
            exitings(5)
            tc()


from colorama import init
from time import sleep as dd
from sys import exit as tc
import platform as pd1
from sys import platform as pd2
from random import choice
import subprocess
os1=pd1.system()#大写
os2=pd2#
colors=[
'\033[1;51m'
'\033[1;43m','\033[1;42m','\033[1;31m',
'\033[1;32m','\033[1;33m','\033[1;34m',
'\033[1;35m','\033[1;36m','\033[1;345m',
'\033[1;46m','\033[1;41m',
'\033[1;45m']

def pdios():
    if (os1=='Windows') or (os2=='windows'):
        init(autoreset=True)
        choice_color=choice(colors)
        subprocess.call("cls", shell=True)
        print('\033[1;1m'+('sycc:'.title().center(5))+'欢迎%sWindows%s用户\n'%(choice_color,'\033[0m'))
        
    elif (os1=='Linux') or (os2=='linux'):
        init(autoreset=False)
        subprocess.call("clear", shell=True)
            #print('\033[1;1m'+('sycc:'.title().center(5))+'\033[0m欢迎%sLinux用户\n'%colors[i])
        choice_color=choice(colors)
        print('\033[1;1m'+('sycc:'.title().center(5))+'\033[0m欢迎%sLinux%s用户\n'%(choice_color,'\033[0m'))
            #print(choice_color.split('\033['))
        dd(1)      
    else:
        print('虹源三式提醒您:不支持该系统,请联系lwb29@qq.com')
        dd(2)
        tc('exit')
